summaryrefslogtreecommitdiffstats
path: root/src/H5Dio.c
diff options
context:
space:
mode:
authorMohamad Chaarawi <chaarawi@hdfgroup.org>2014-06-13 15:48:28 (GMT)
committerMohamad Chaarawi <chaarawi@hdfgroup.org>2014-06-13 15:48:28 (GMT)
commit8df5a96ccb3d60bc38d9f1b6d0d774d55afbb7a6 (patch)
treee832fadb71d5b27a087e14c2b679a67e20f906ac /src/H5Dio.c
parent3e1e5f166a1316573ea81b96178bb6a4fa3654a2 (diff)
parent25ba47bc97bd7dd3f9f9ee0c13d04c1ea041dd7b (diff)
downloadhdf5-8df5a96ccb3d60bc38d9f1b6d0d774d55afbb7a6.zip
hdf5-8df5a96ccb3d60bc38d9f1b6d0d774d55afbb7a6.tar.gz
hdf5-8df5a96ccb3d60bc38d9f1b6d0d774d55afbb7a6.tar.bz2
[svn-r25275] merge from trunk.
Diffstat (limited to 'src/H5Dio.c')
-rw-r--r--src/H5Dio.c30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/H5Dio.c b/src/H5Dio.c
index b83ed88..788c305 100644
--- a/src/H5Dio.c
+++ b/src/H5Dio.c
@@ -97,14 +97,14 @@ H5FL_BLK_DEFINE(type_conv);
* passed to this function with the PLIST_ID argument.
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
* that the entire file data space is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
* the memory data space is the same as the file data space
* defined when the dataset was created.
*
* The number of elements in the memory data space must match
* the number of elements in the file data space.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
* case the default data transfer properties are used.
@@ -129,7 +129,7 @@ H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id,
plist_id, buf);
if(mem_space_id < 0 || file_space_id < 0)
- HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a data space")
+ HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a dataspace")
/* Get the default dataset transfer property list if the user didn't provide one */
if (H5P_DEFAULT == plist_id)
@@ -168,14 +168,14 @@ done:
* PLIST_ID argument.
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
* that the entire file data space is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
* the memory data space is the same as the file data space
* defined when the dataset was created.
*
* The number of elements in the memory data space must match
* the number of elements in the file data space.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
* case the default data transfer properties are used.
@@ -342,7 +342,7 @@ H5D__read(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
hbool_t type_info_init = FALSE; /* Whether the datatype info has been initialized */
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
/* data space with rank equal to that of */
/* file_space. */
/* */
/* This field is only used if */
@@ -396,7 +396,7 @@ H5D__read(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
/* Make certain that the number of elements in each selection is the same */
if(nelmts != (hsize_t)H5S_GET_SELECT_NPOINTS(file_space))
- HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest data spaces have different sizes")
+ HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest dataspaces have different sizes")
/* Check for a NULL buffer, after the H5S_ALL dataspace selection has been handled */
if(NULL == buf) {
@@ -558,7 +558,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
hbool_t type_info_init = FALSE; /* Whether the datatype info has been initialized */
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
/* data space with rank equal to that of */
/* file_space. */
/* */
/* This field is only used if */
@@ -650,7 +650,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
/* Make certain that the number of elements in each selection is the same */
if(nelmts != (hsize_t)H5S_GET_SELECT_NPOINTS(file_space))
- HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest data spaces have different sizes")
+ HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "src and dest dataspaces have different sizes")
/* Check for a NULL buffer, after the H5S_ALL dataspace selection has been handled */
if(NULL == buf) {
@@ -704,7 +704,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
/* Retrieve dataset properties */
/* <none needed currently> */
/* Allocate data space and initialize it if it hasn't been. */
if(nelmts > 0 && dataset->shared->dcpl_cache.efl.nused == 0 &&
!(*dataset->shared->layout.ops->is_space_alloc)(&dataset->shared->layout.storage)) {
hssize_t file_nelmts; /* Number of elements in file dataset's dataspace */
@@ -909,7 +909,7 @@ H5D__typeinfo_init(const H5D_t *dset, const H5D_dxpl_cache_t *dxpl_cache,
} /* end else */
/*
* Locate the type conversion function and data space conversion
* functions, and set up the element numbering information. If a data
* type conversion is necessary then register datatype atoms. Data type
* conversion is necessary if the user has set the `need_bkg' to a high
@@ -97,14 +97,14 @@ H5FL_BLK_DEFINE(type_conv);
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
- * that the entire file data space is to be referenced.
+ * that the entire file dataspace is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
@@ -97,14 +97,14 @@ H5FL_BLK_DEFINE(type_conv);
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
- * the memory data space is the same as the file data space
+ * the memory dataspace is the same as the file dataspace
* defined when the dataset was created.
*
@@ -97,14 +97,14 @@ H5FL_BLK_DEFINE(type_conv);
* defined when the dataset was created.
*
- * The number of elements in the memory data space must match
- * the number of elements in the file data space.
+ * The number of elements in the memory dataspace must match
+ * the number of elements in the file dataspace.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
@@ -168,14 +168,14 @@ done:
*
* The FILE_SPACE_ID can be the constant H5S_ALL which indicates
- * that the entire file data space is to be referenced.
+ * that the entire file dataspace is to be referenced.
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
@@ -168,14 +168,14 @@ done:
*
* The MEM_SPACE_ID can be the constant H5S_ALL in which case
- * the memory data space is the same as the file data space
+ * the memory dataspace is the same as the file dataspace
* defined when the dataset was created.
*
@@ -168,14 +168,14 @@ done:
* defined when the dataset was created.
*
- * The number of elements in the memory data space must match
- * the number of elements in the file data space.
+ * The number of elements in the memory dataspace must match
+ * the number of elements in the file dataspace.
*
* The PLIST_ID can be the constant H5P_DEFAULT in which
@@ -342,7 +342,7 @@ H5D__read(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
- /* data space with rank equal to that of */
+ /* dataspace with rank equal to that of */
/* file_space. */
/* */
@@ -558,7 +558,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
H5S_t * projected_mem_space = NULL; /* If not NULL, ptr to dataspace containing a */
/* projection of the supplied mem_space to a new */
- /* data space with rank equal to that of */
+ /* dataspace with rank equal to that of */
/* file_space. */
/* */
@@ -704,7 +704,7 @@ H5D__write(H5D_t *dataset, hid_t mem_type_id, const H5S_t *mem_space,
/* Retrieve dataset properties */
/* <none needed currently> */
- /* Allocate data space and initialize it if it hasn't been. */
+ /* Allocate dataspace and initialize it if it hasn't been. */
if(nelmts > 0 && dataset->shared->dcpl_cache.efl.nused == 0 &&
!(*dataset->shared->layout.ops->is_space_alloc)(&dataset->shared->layout.storage)) {
@@ -909,7 +909,7 @@ H5D__typeinfo_init(const H5D_t *dset, const H5D_dxpl_cache_t *dxpl_cache,
} /* end else */
/*
- * Locate the type conversion function and data space conversion
+ * Locate the type conversion function and dataspace conversion
* functions, and set up the element numbering information. If a data
* type conversion is necessary then register datatype atoms. Data type